import React, { useState, useEffect } from 'react';
import '../styles/popup.css';

const popupMessages = [
  "🌟 君の異次元力を活かせるのは当社だけ！",
  "💫 今なら入社特典で好きな次元に1回無料で行けます！",
  "🎮 レトロな技術力、待ってます！",
  "🌈 平行世界の自分と相談してからでも遅くない！",
  "⭐ 履歴書は量子もつれで送信できます！",
  "🎯 あなたの座標軸を当社に合わせませんか？",
  "🚀 時空を超えた働き方改革実施中！",
  "💝 社食は異次元シェフが作ります！",
  "🎪 社内イベントは全て異次元空間で開催！"
];

function AggressivePopups() {
  const [activePopups, setActivePopups] = useState([]);
  const [popupCount, setPopupCount] = useState(0);

  const createPopup = () => {
    if (activePopups.length >= 5) return; // 同時に表示する最大数

    const id = Date.now();
    const message = popupMessages[Math.floor(Math.random() * popupMessages.length)];
    const position = {
      top: Math.random() * (window.innerHeight - 200),
      left: Math.random() * (window.innerWidth - 300)
    };

    const newPopup = { id, message, position };
    setActivePopups(prev => [...prev, newPopup]);
    setPopupCount(prev => prev + 1);

    // 一定時間後に自動で消える
    setTimeout(() => {
      setActivePopups(prev => prev.filter(popup => popup.id !== id));
    }, 5000);
  };

  useEffect(() => {
    // 初回表示時のポップアップ
    setTimeout(createPopup, 2000);

    // 定期的にポップアップを表示
    const interval = setInterval(() => {
      if (popupCount < 30) { // 合計表示回数の制限
        createPopup();
      }
    }, 8000);

    return () => clearInterval(interval);
  }, [popupCount]);

  return (
    <>
      {activePopups.map(popup => (
        <div
          key={popup.id}
          className="win95-popup"
          style={{
            top: popup.position.top,
            left: popup.position.left
          }}
        >
          <div className="win95-popup-title">
            採用担当からのメッセージ！
            <button
              className="win95-close-button"
              onClick={() => setActivePopups(prev => 
                prev.filter(p => p.id !== popup.id)
              )}
            >
              ×
            </button>
          </div>
          <div className="win95-popup-content">
            {popup.message}
          </div>
          <div className="win95-popup-buttons">
            <button className="win95-button" onClick={() => window.location.href = '/careers'}>
              応募する！
            </button>
            <button className="win95-button" onClick={() => setActivePopups(prev => 
              prev.filter(p => p.id !== popup.id)
            )}>
              また今度
            </button>
          </div>
        </div>
      ))}
    </>
  );
}

export default AggressivePopups; 